﻿Imports System.Collections.ObjectModel
Imports System.ComponentModel
Imports System.Runtime.CompilerServices

Class MainWindow
	Implements INotifyPropertyChanged

	Private Sub MainWindow_Loaded(sender As Object, e As RoutedEventArgs) Handles Me.Loaded

		KundenListeView = CollectionViewSource.GetDefaultView(KundenListe)
		KundenListeView.Filter = AddressOf KundenListeViewFilter

		For i As Integer = 0 To 9
			KundenListe.Add(New Kunde With {.KundeName = "Michael" & i.ToString})
		Next

		AuftragsListeView = CollectionViewSource.GetDefaultView(AuftragsListe)
		AuftragsListeView.Filter = AddressOf AuftragsListeViewFilter

		For i As Integer = 0 To 9
			AuftragsListe.Add(New Auftrag With {.Auftragsdatum = DateTime.Today.AddDays(i), .AuftragsKunde = New Kunde With {.KundeName = "Michael" & i.ToString}.KundeName, .BruttoPreis = 20 + i})
		Next
		Me.DataContext = Me
	End Sub

	Private _kundenliste As New ObservableCollection(Of Kunde)
	Public Property KundenListe() As ObservableCollection(Of Kunde)
		Get
			Return _kundenliste
		End Get
		Set(ByVal value As ObservableCollection(Of Kunde))
			_kundenliste = value
			RaisePropertyChanged()
		End Set
	End Property

	Private _kundenlisteview As ICollectionView
	Public Property KundenListeView() As ICollectionView
		Get
			Return _kundenlisteview
		End Get
		Set(ByVal value As ICollectionView)
			_kundenlisteview = value
			RaisePropertyChanged()
		End Set
	End Property

	Private _kundenlistefiltertext As String
	Public Property KundenListeFilterText() As String
		Get
			Return _kundenlistefiltertext
		End Get
		Set(ByVal value As String)
			_kundenlistefiltertext = value
			KundenListeView.Refresh()
			RaisePropertyChanged()
		End Set
	End Property

	Function KundenListeViewFilter(obj As Object) As Boolean
		If String.IsNullOrEmpty(KundenListeFilterText) Then Return True

		If obj IsNot Nothing Then
			Dim CurrentKunde As Kunde = CType(obj, Kunde)

			If Not String.IsNullOrEmpty(CurrentKunde.KundeName) Then
				Return CurrentKunde.KundeName.ToLower.Contains(KundenListeFilterText.ToLower)
			Else
				Return True
			End If

		Else
			Return True
		End If
	End Function

	Private _auftragsliste As New ObservableCollection(Of Auftrag)
	Public Property AuftragsListe() As ObservableCollection(Of Auftrag)
		Get
			Return _auftragsliste
		End Get
		Set(ByVal value As ObservableCollection(Of Auftrag))
			_auftragsliste = value
			RaisePropertyChanged()
		End Set
	End Property

	Private _auftragslisteview As ICollectionView
	Public Property AuftragsListeView() As ICollectionView
		Get
			Return _auftragslisteview
		End Get
		Set(ByVal value As ICollectionView)
			_auftragslisteview = value
			RaisePropertyChanged()
		End Set
	End Property

	Private _auftragslistefilterdatestart As DateTime? = Date.Today.AddDays(2)
	Public Property AuftragsListeFilterDateStart() As DateTime?
		Get
			Return _auftragslistefilterdatestart
		End Get
		Set(ByVal value As DateTime?)
			_auftragslistefilterdatestart = value
			If value IsNot Nothing Then VonValid = True
			RaisePropertyChanged()
			AuftragsListeView.Refresh()
		End Set
	End Property

	Private _auftragslistefilterdateende As DateTime? ' = Date.Today.AddDays(8)
	Public Property AuftragsListeFilterDateEnde() As DateTime?
		Get
			Return _auftragslistefilterdateende
		End Get
		Set(ByVal value As DateTime?)
			_auftragslistefilterdateende = value
			If value IsNot Nothing Then BisValid = True
			RaisePropertyChanged()
			AuftragsListeView.Refresh()
		End Set
	End Property
	Private _BisValid As Boolean = _auftragslistefilterdateende IsNot Nothing
	Public Property BisValid() As Boolean
		Get
			Return _BisValid
		End Get
		Set(ByVal value As Boolean)
			If _BisValid = value Then Return
			_BisValid = value
			If Not value Then AuftragsListeFilterDateEnde = Nothing
			RaisePropertyChanged()
		End Set
	End Property
	Private _VonValid As Boolean = _auftragslistefilterdatestart IsNot Nothing
	Public Property VonValid() As Boolean
		Get
			Return _VonValid
		End Get
		Set(ByVal value As Boolean)
			If _VonValid = value Then Return
			_VonValid = value
			If Not value Then AuftragsListeFilterDateStart = Nothing
			RaisePropertyChanged()
		End Set
	End Property
	Private _FilterOn As Boolean = True
	Public Property FilterOn() As Boolean
		Get
			Return _FilterOn
		End Get
		Set(ByVal value As Boolean)
			If _FilterOn = value Then Return
			_FilterOn = value
			RaisePropertyChanged()
			AuftragsListeView.Refresh()
		End Set
	End Property

	Function AuftragsListeViewFilter(obj As Object) As Boolean
		If Not FilterOn Then Return True
		Dim dts = {_auftragslistefilterdatestart.GetValueOrDefault(Date.MinValue), _auftragslistefilterdateende.GetValueOrDefault(Date.MaxValue.AddDays(-1))}
		Dim dt = CType(obj, Auftrag).Auftragsdatum
		Return dt >= dts(0) AndAlso dt < dts(1).AddDays(1)
	End Function

	Public Event PropertyChanged As PropertyChangedEventHandler Implements INotifyPropertyChanged.PropertyChanged
	Protected Overridable Sub RaisePropertyChanged(<CallerMemberName> Optional ByVal prop As String = "")
		RaiseEvent PropertyChanged(Me, New PropertyChangedEventArgs(prop))
	End Sub

End Class